@@ -40,7 +40,7 @@ const char* const RKEY_PREFAB_PATH = "user/paths/prefabPath";
  * As long as no external module/plugin files are removed this number is safe to stay 
  * as it is. Keep this number compatible to std::size_t, i.e. unsigned.
  */
-#define MODULE_COMPATIBILITY_LEVEL 20170327
+#define MODULE_COMPATIBILITY_LEVEL 20180104
 
 // A function taking an error title and an error message string, invoked in debug builds
 // for things like ASSERT_MESSAGE and ERROR_MESSAGE
@@ -218,21 +218,6 @@ public:
  */
 typedef std::shared_ptr<RegisterableModule> RegisterableModulePtr;
 
-/**
- * A ModuleObserver can be attached/detached to certain modules (like the
- * MaterialManager or the OpenGLRendersystem) to get notified about
- * realise() or unrealise() events.
- * (Might be replaced by the sigc signal framework eventually)
- */
-class ModuleObserver
-{
-public:
-	virtual ~ModuleObserver() {}
-
-	virtual void unrealise() = 0;
-	virtual void realise() = 0;
-};
-
 /**
  * Interface for the module registry. This is the owner and manager of all
  * RegisterableModules defined in DLLs and the main binary.
