@@ -2,6 +2,7 @@
 
 #include <cstddef>
 #include "imodule.h"
+#include "ivolumetest.h"
 #include <memory>
 #include <sigc++/signal.h>
 
@@ -34,9 +35,98 @@ class Face;
 class Brush;
 class Patch;
 
-namespace selection { struct WorkZone; }
+namespace selection 
+{ 
+	
+struct WorkZone; 
 
-const std::string MODULE_SELECTIONSYSTEM("SelectionSystem");
+/**
+* A Manipulator is a renderable object which contains one or more
+* ManipulatorComponents, each of which can be manipulated by the user. For
+* example, the rotation Manipulator draws several circles which cause rotations
+* around specific axes.
+*/
+class Manipulator
+{
+public:
+	// Manipulator type enum, user-defined manipulators should return "Custom"
+	enum Type
+	{
+		Drag,
+		Translate,
+		Rotate,
+		Scale,
+		Clip,
+		ModelScale,
+		Custom
+	};
+
+	/**
+	* Part of a Manipulator which can be operated upon by the user.
+	*
+	* \see Manipulator
+	*/
+	class Component
+	{
+	public:
+		virtual ~Component() {}
+
+		/**
+		 * Called when the user successfully activates this component. The calling code provides
+		 * information about the view we're operating in, the starting device coords and the
+		 * location of the current selection pivot.
+		 */
+		virtual void beginTransformation(const Matrix4& pivot2world, const VolumeTest& view, const Vector2& devicePoint) = 0;
+
+		struct Constraint
+		{
+			enum Flags
+			{
+				Unconstrained = 0,	// no keyboard modifier held
+				Type1 = 1 << 0,		// usually: shift held down
+				Grid =  1 << 1,		// usually: ctrl NOT held down
+				Type3 = 1 << 2,		// usually: alt held down
+			};
+		};
+
+		/**
+		 * Called during mouse movement, the component is asked to calculate the deltas and distances
+		 * it needs to perform the translation/rotation/scale/whatever the operator does on the selected objects.
+		 * The pivot2world transform relates to the original pivot location at the time the transformation started.
+		 * If the constrained flags are not 0, they indicate the user is holding down a key during movement, 
+		 * usually the SHIFT or CTRL key. It's up to the component to decide how to handle the constraint.
+		 */
+		virtual void transform(const Matrix4& pivot2world, const VolumeTest& view, const Vector2& devicePoint, unsigned int flags) = 0;
+	};
+
+	virtual ~Manipulator() {}
+
+	// ID and Type management
+	virtual std::size_t getId() const = 0;
+	virtual void setId(std::size_t id) = 0;
+
+	virtual Type getType() const = 0;
+
+	/**
+	* Get the currently-active ManipulatorComponent. This is determined by the
+	* most recent selection test.
+	*/
+	virtual Component* getActiveComponent() = 0;
+
+	virtual void testSelect(const render::View& view, const Matrix4& pivot2world) {}
+
+	// Renders the manipulator's visual representation to the scene
+	virtual void render(RenderableCollector& collector, const VolumeTest& volume) = 0;
+
+	virtual void setSelected(bool select) = 0;
+	virtual bool isSelected() const = 0;
+
+	// Manipulators should indicate whether component editing is supported or not
+	virtual bool supportsComponentManipulation() const = 0;
+};
+typedef std::shared_ptr<Manipulator> ManipulatorPtr;
+
+}
 
 class SelectionSystem :
 	public RegisterableModule
@@ -65,15 +155,6 @@ public:
 		eFace,
 	};
 
-	// The possible manipulator modes
-	enum EManipulatorMode {
-		eTranslate,
-		eRotate,
-		eScale,
-		eDrag,
-		eClip,
-	};
-
 	/** greebo: An SelectionSystem::Observer gets notified
 	 * as soon as the selection is changed.
 	 */
@@ -92,14 +173,23 @@ public:
 	virtual void addObserver(Observer* observer) = 0;
 	virtual void removeObserver(Observer* observer) = 0;
 
+	// Returns the ID of the registered manipulator
+	virtual std::size_t registerManipulator(const selection::ManipulatorPtr& manipulator) = 0;
+	virtual void unregisterManipulator(const selection::ManipulatorPtr& manipulator) = 0;
+
+	virtual selection::Manipulator::Type getActiveManipulatorType() = 0;
+
+	// Returns the currently active Manipulator, which is always non-null
+	virtual const selection::ManipulatorPtr& getActiveManipulator() = 0;
+	virtual void setActiveManipulator(std::size_t manipulatorId) = 0;
+	virtual void setActiveManipulator(selection::Manipulator::Type manipulatorType) = 0;
+
 	virtual const SelectionInfo& getSelectionInfo() = 0;
 
   virtual void SetMode(EMode mode) = 0;
   virtual EMode Mode() const = 0;
   virtual void SetComponentMode(EComponentMode mode) = 0;
   virtual EComponentMode ComponentMode() const = 0;
-  virtual void SetManipulatorMode(EManipulatorMode mode) = 0;
-  virtual EManipulatorMode ManipulatorMode() const = 0;
 
   virtual std::size_t countSelected() const = 0;
   virtual std::size_t countSelectedComponents() const = 0;
@@ -185,20 +275,17 @@ public:
     /// Signal emitted when the selection is changed
     virtual SelectionChangedSignal signal_selectionChanged() const = 0;
 
-    virtual void translateSelected(const Vector3& translation) = 0;
-    virtual void rotateSelected(const Quaternion& rotation) = 0;
-    virtual void scaleSelected(const Vector3& scaling) = 0;
+	virtual const Matrix4& getPivot2World() = 0;
+    virtual void pivotChanged() = 0;
     
-    virtual void pivotChanged() const = 0;
-    
-    virtual bool SelectManipulator(const render::View& view, const Vector2& devicePoint, const Vector2& deviceEpsilon) = 0;
+	// Feedback events invoked by the ManipulationMouseTool
+	virtual void onManipulationStart() = 0;
+	virtual void onManipulationChanged() = 0;
+	virtual void onManipulationEnd() = 0;
+
     virtual void SelectPoint(const render::View& view, const Vector2& devicePoint, const Vector2& deviceEpsilon, EModifier modifier, bool face) = 0;
     virtual void SelectArea(const render::View& view, const Vector2& devicePoint, const Vector2& deviceDelta, EModifier modifier, bool face) = 0;
     
-    virtual void MoveSelected(const render::View& view, const Vector2& devicePoint) = 0;
-    virtual void endMove() = 0;
-    virtual void cancelMove() = 0;
-
 	/**
 	 * Returns the current "work zone", which is defined by the
 	 * currently selected elements. Each time a scene node is selected,
@@ -213,6 +300,8 @@ public:
 	virtual const selection::WorkZone& getWorkZone() = 0;
 };
 
+const char* const MODULE_SELECTIONSYSTEM("SelectionSystem");
+
 inline SelectionSystem& GlobalSelectionSystem() {
 	// Cache the reference locally
 	static SelectionSystem& _selectionSystem(
