@@ -96,17 +96,10 @@ public:
 
 	void render(RenderableCollector& collector, const VolumeTest& volume, const Matrix4& localToWorld) const
 	{
-		collector.PushState();
-
 		// greebo: Commented this out to avoid the point from being moved along with the view.
 		//Pivot2World_worldSpace(m_localToWorld, localToWorld, volume.GetModelview(), volume.GetProjection(), volume.GetViewport());
 
-		collector.setHighlightFlag(RenderableCollector::Highlight::Primitives, false);
-		collector.SetState(_shader, RenderableCollector::eWireframeOnly);
-		collector.SetState(_shader, RenderableCollector::eFullMaterials);
-		collector.addRenderable(*this, localToWorld);
-
-		collector.PopState();
+		collector.addRenderable(_shader, *this, localToWorld);
 	}
 };
 
