@@ -10,8 +10,8 @@
 
 #include "MultiMonitor.h"
 #include "dialog/MessageBox.h"
-#include <boost/algorithm/string/predicate.hpp>
-#include <boost/format.hpp>
+#include "string/predicate.h"
+#include "string/case_conv.h"
 #include <wx/app.h>
 
 namespace wxutil
@@ -21,15 +21,8 @@ FileChooser::FileChooser(const std::string& title,
 						 bool open,
 						 const std::string& fileType,
 						 const std::string& defaultExt) :
-	_dialog(new wxFileDialog(GlobalMainFrame().getWxTopLevelWindow(), title, wxEmptyString, 
-			 wxEmptyString, wxFileSelectorDefaultWildcardStr, getStyle(open))),
-	_title(title),
-	_fileType(fileType),
-	_defaultExt(defaultExt),
-	_open(open)
-{
-	construct();
-}
+	FileChooser(GlobalMainFrame().getWxTopLevelWindow(), title, open, fileType, defaultExt)
+{}
 
 FileChooser::FileChooser(wxWindow* parentWindow,
 						 const std::string& title,
@@ -65,6 +58,9 @@ void FileChooser::construct()
 		_title = _open ? _("Open File") : _("Save File");
 	}
 
+	// Make default extension lowercase
+	string::to_lower(_defaultExt);
+
 	int defaultFormatIdx = 0;
 	int curFormatIdx = 0;
 
@@ -73,7 +69,7 @@ void FileChooser::construct()
 
 	for (FileTypePatterns::const_iterator i = patterns.begin(); i != patterns.end(); ++i)
 	{
-		if (!_open && _fileType == "map")
+		if (!_open && _fileType == filetype::TYPE_MAP)
 		{
 			std::set<map::MapFormatPtr> formats = GlobalMapFormatManager().getMapFormatList(i->extension);
 
@@ -107,7 +103,15 @@ void FileChooser::construct()
 			filter.caption = i->name + " (" + i->pattern + ")";
 			filter.filter = i->pattern;
 
+			// Pre-select the filter matching the default extension
+			if (i->extension == _defaultExt)
+			{
+				defaultFormatIdx = curFormatIdx;
+			}
+
 			_fileFilters.push_back(filter);
+
+			++curFormatIdx;
 		}
 	}
 
@@ -176,7 +180,7 @@ std::string FileChooser::getSelectedFileName()
 	if (!_open											// save operation
 	    && !fileName.empty() 							// valid filename
 	    && !_defaultExt.empty()							// non-empty default extension
-	    && !boost::algorithm::iends_with(fileName, _defaultExt)) // no default extension
+	    && !string::iends_with(fileName, _defaultExt)) // no default extension
 	{
 		fileName.append(_defaultExt);
 	}
