@@ -15,6 +15,7 @@
 #include "AIVocalSetPropertyEditor.h"
 #include "FixupMapDialog.h"
 #include "AIEditingPanel.h"
+#include "MissionInfoEditDialog.h"
 
 class EditingModule :
 	public RegisterableModule
@@ -66,6 +67,16 @@ public:
 			"FixupMapDialog"
 		);
 
+		GlobalCommandSystem().addCommand("MissionInfoEditDialog", ui::MissionInfoEditDialog::ShowDialog);
+		GlobalEventManager().addCommand("MissionInfoEditDialog", "MissionInfoEditDialog");
+
+		GlobalUIManager().getMenuManager().add("main/map",
+			"MissionInfoEditDialog", ui::menuItem,
+			_("Edit Package Info (darkmod.txt)..."), // caption
+			"sr_icon_readable.png", // icon
+			"MissionInfoEditDialog"
+		);
+
 		GlobalRadiant().signal_radiantStarted().connect(
 			sigc::ptr_fun(ui::AIEditingPanel::onRadiantStartup)
 		);	
