@@ -46,7 +46,7 @@ void GuiManager::reloadGui(const std::string& guiPath)
 GuiType GuiManager::getGuiType(const std::string& guiPath)
 {
 	// Get the GUI (will load the file if necessary)
-	GuiPtr gui = getGui(guiPath);
+	GuiPtr gui = std::static_pointer_cast<Gui>(getGui(guiPath));
 
 	GuiInfoMap::iterator found = _guis.find(guiPath);
 
@@ -118,7 +118,7 @@ void GuiManager::clear()
 	_errorList.clear();
 }
 
-GuiPtr GuiManager::getGui(const std::string& guiPath)
+IGuiPtr GuiManager::getGui(const std::string& guiPath)
 {
     ensureGuisLoaded();
 
@@ -173,8 +173,7 @@ GuiPtr GuiManager::loadGui(const std::string& guiPath)
 	// Construct a Code Tokeniser, which is able to handle #includes
 	try
 	{
-		std::string whiteSpace = std::string(parser::WHITESPACE) + ",";
-		parser::CodeTokeniser tokeniser(file, whiteSpace.c_str(), "{}(),;");
+		parser::CodeTokeniser tokeniser(file, parser::WHITESPACE, "{}(),;");
 
 		info.gui = Gui::createFromTokens(tokeniser);
 		info.type = UNDETERMINED;
@@ -192,10 +191,35 @@ GuiPtr GuiManager::loadGui(const std::string& guiPath)
 	}
 }
 
-GuiManager& GuiManager::Instance()
+const std::string& GuiManager::getName() const
 {
-	static GuiManager _instance;
-	return _instance;
+	static std::string _name(MODULE_GUIMANAGER);
+	return _name;
+}
+
+const StringSet& GuiManager::getDependencies() const
+{
+	static StringSet _dependencies;
+
+	if (_dependencies.empty())
+	{
+		_dependencies.insert(MODULE_VIRTUALFILESYSTEM);
+	}
+
+	return _dependencies;
+}
+
+void GuiManager::initialiseModule(const ApplicationContext& ctx)
+{
+	rMessage() << getName() << "::initialiseModule called." << std::endl;
+
+	// Search the VFS for GUIs
+	init();
+}
+
+void GuiManager::shutdownModule()
+{
+	clear();
 }
 
 } // namespace gui
