@@ -1,7 +1,6 @@
 // Precompiled header used by the S/R Editor module
 #pragma once
 
-#define DR_PRECOMPILED_BOOST
 #define DR_PRECOMPILED_WXWIDGETS
 
 #include "precompiled_main.h"
@@ -10,5 +9,5 @@
 #include "wxutil/TreeModel.h"
 #include "wxutil/dialog/MessageBox.h"
 
-#include <boost/format.hpp>
+#include <fmt/format.h>
 #include "string/string.h"
