@@ -1,14 +1,13 @@
 // Precompiled header used by the Entity module
 #pragma once
 
-#define DR_PRECOMPILED_BOOST
 #define DR_PRECOMPILED_INTERFACES
 #define DR_PRECOMPILED_MATH
 
 #include "precompiled_main.h"
 
 // Some entity specifics
-#include <boost/format.hpp>
+#include <fmt/format.h>
 #include <functional>
 
 #include "string/string.h"
