@@ -4,9 +4,10 @@
 #include "ieclass.h"
 #include "ifilter.h"
 #include <regex>
-#include <boost/algorithm/string/erase.hpp>
+#include <algorithm>
 
-namespace filters {
+namespace filters
+{
 
 XMLFilter::XMLFilter(const std::string& name, bool readOnly) :
 	_name(name),
@@ -34,7 +35,7 @@ bool XMLFilter::isVisible(const FilterRule::Type type, const std::string& name)
 			continue;
 		}
 
-		// If we have a rule for this item, use boost's regex to match the query name
+		// If we have a rule for this item, use a regex to match the query name
 		// against the "match" parameter
 		std::regex ex(ruleIter->match);
 
@@ -120,7 +121,10 @@ void XMLFilter::setRules(const FilterRules& rules) {
 void XMLFilter::updateEventName() {
 	// Construct the eventname out of the filtername (strip the spaces and add "Filter" prefix)
 	_eventName = _name;
-	boost::algorithm::erase_all(_eventName, " ");
+
+	// Strip all spaces from the string
+	_eventName.erase(std::remove(_eventName.begin(), _eventName.end(), ' '), _eventName.end());
+
 	_eventName = "Filter" + _eventName;
 }
 
