@@ -63,7 +63,7 @@ RenderablePicoModel::RenderablePicoModel(const RenderablePicoModel& other) :
 		// Copy-construct the other surface, inheriting any applied scale
 		_surfVec[i].surface = std::make_shared<RenderablePicoSurface>(*(other._surfVec[i].surface));
 		_surfVec[i].originalSurface = other._surfVec[i].originalSurface;
-		_surfVec[i].activeMaterial = _surfVec[i].surface->getDefaultMaterial();
+		_surfVec[i].surface->setActiveMaterial(_surfVec[i].surface->getDefaultMaterial());
 	}
 }
 
@@ -86,27 +86,44 @@ void RenderablePicoModel::disconnectUndoSystem(IMapFileChangeTracker& changeTrac
 	GlobalUndoSystem().releaseStateSaver(*this);
 }
 
-// Front end renderable submission
-void RenderablePicoModel::submitRenderables(RenderableCollector& rend,
-											const Matrix4& localToWorld,
-											const IRenderEntity& entity)
+void RenderablePicoModel::foreachVisibleSurface(const std::function<void(const Surface& s)>& func) const
 {
-	// Submit renderables from each surface
-	for (SurfaceList::iterator i = _surfVec.begin(); i != _surfVec.end(); ++i)
+	for (const Surface& surface : _surfVec)
 	{
-		assert(i->shader);
+		assert(surface.shader);
 
-		// Check if the surface's shader is filtered, if not then submit it for
-		// rendering
-		const MaterialPtr& surfaceShader = i->shader->getMaterial();
+		// Check if the surface's shader is filtered, if not then submit it for rendering
+		const MaterialPtr& surfaceShader = surface.shader->getMaterial();
 
 		if (surfaceShader->isVisible())
 		{
-			i->surface->submitRenderables(rend, localToWorld, i->shader, entity);
+			func(surface);
 		}
 	}
 }
 
+void RenderablePicoModel::renderSolid(RenderableCollector& rend, const Matrix4& localToWorld,
+	const IRenderEntity& entity, const LightList& lights) const
+{
+	// Submit renderables from each surface
+	foreachVisibleSurface([&](const Surface& s)
+	{
+		// Submit the ordinary shader for material-based rendering
+		rend.addRenderable(s.shader, *s.surface, localToWorld, entity, lights);
+	});
+}
+
+void RenderablePicoModel::renderWireframe(RenderableCollector& rend, const Matrix4& localToWorld,
+	const IRenderEntity& entity) const
+{
+	// Submit renderables from each surface
+	foreachVisibleSurface([&](const Surface& s)
+	{
+		// Submit the wireframe shader for non-shaded renderers
+		rend.addRenderable(entity.getWireShader(), *s.surface, localToWorld, entity);
+	});
+}
+
 void RenderablePicoModel::setRenderSystem(const RenderSystemPtr& renderSystem)
 {
 	_renderSystem = renderSystem;
@@ -205,7 +222,7 @@ void RenderablePicoModel::applySkin(const ModelSkin& skin)
 		 ++i)
 	{
 		const std::string& defaultMaterial = i->surface->getDefaultMaterial();
-		const std::string& activeMaterial = i->activeMaterial;
+		const std::string& activeMaterial = i->surface->getActiveMaterial();
 
 		// Look up the remap for this surface's material name. If there is a remap
 		// change the Shader* to point to the new shader.
@@ -214,12 +231,12 @@ void RenderablePicoModel::applySkin(const ModelSkin& skin)
 		if (!remap.empty() && remap != activeMaterial)
 		{
 			// Save the remapped shader name
-			i->activeMaterial = remap;
+			i->surface->setActiveMaterial(remap);
 		}
 		else if (remap.empty() && activeMaterial != defaultMaterial)
 		{
 			// No remap, so reset our shader to the original unskinned shader
-			i->activeMaterial = defaultMaterial;
+			i->surface->setActiveMaterial(defaultMaterial);
 		}
 	}
 
@@ -238,7 +255,7 @@ void RenderablePicoModel::captureShaders()
 	{
 		if (renderSystem)
 		{
-			i->shader = renderSystem->capture(i->activeMaterial);
+			i->shader = renderSystem->capture(i->surface->getActiveMaterial());
 		}
 		else
 		{
@@ -252,11 +269,9 @@ void RenderablePicoModel::updateMaterialList() const
 {
 	_materialList.clear();
 
-	for (SurfaceList::const_iterator i = _surfVec.begin();
-		 i != _surfVec.end();
-		 ++i)
+	for (const auto& s : _surfVec)
 	{
-		_materialList.push_back(i->activeMaterial);
+		_materialList.push_back(s.surface->getActiveMaterial());
 	}
 }
 
