@@ -47,10 +47,6 @@ private:
 		// The (unmodified) surface object
 		RenderablePicoSurfacePtr originalSurface;
 
-		// The name of the material (with skin applied)
-		// The default material name is stored on the surface
-		std::string activeMaterial;
-
 		// The shader this surface is using
 		ShaderPtr shader;
 
@@ -108,6 +104,8 @@ private:
 
 	void applyScaleToSurfaces();
 
+	void foreachVisibleSurface(const std::function<void(const Surface& s)>& func) const;
+
 public:
 
 	/**
@@ -126,20 +124,10 @@ public:
 	void connectUndoSystem(IMapFileChangeTracker& changeTracker);
 	void disconnectUndoSystem(IMapFileChangeTracker& changeTracker);
 
-	/**
-	 * Front-end render function used by the main collector.
-	 *
-	 * @param rend
-	 * The sorting RenderableCollector object which accepts renderable geometry.
-	 *
-	 * @param localToWorld
-	 * Object to world-space transform.
-	 *
-	 * @param entity
-	 * The entity this model is attached to.
-	 */
-	void submitRenderables(RenderableCollector& rend, const Matrix4& localToWorld,
-						   const IRenderEntity& entity);
+	void renderSolid(RenderableCollector& rend, const Matrix4& localToWorld,
+		const IRenderEntity& entity, const LightList& lights) const;
+	void renderWireframe(RenderableCollector& rend, const Matrix4& localToWorld,
+		const IRenderEntity& entity) const;
 
 	void setRenderSystem(const RenderSystemPtr& renderSystem);
 
