@@ -21,23 +21,24 @@
  *  	GlobalRegistry().exportToFile(node_to_export, absolute_path_to_file);
  */
 
-#include "iregistry.h"		// The Abstract Base Class
+#include "iregistry.h"
 #include <map>
 
 #include "imodule.h"
 #include "RegistryTree.h"
+#include "Autosaver.h"
+
+namespace registry
+{
 
 class XMLRegistry :
 	public Registry
 {
-    // The map of registry key signals. There is one signal per key, but a
-    // signal can of course be connected to multiple slots.
-    typedef std::map<const std::string, sigc::signal<void> > KeySignals;
-    mutable KeySignals _keySignals;
-
 private:
-	// The default import node and toplevel node
-	std::string _topLevelNode;
+	// The map of registry key signals. There is one signal per key, but a
+	// signal can of course be connected to multiple slots.
+	typedef std::map<const std::string, sigc::signal<void> > KeySignals;
+	mutable KeySignals _keySignals;
 
 	// The "install" tree, is basically treated as read-only
 	RegistryTree _standardTree;
@@ -49,10 +50,16 @@ private:
 	// The query counter for some statistics :)
 	unsigned int _queryCounter;
 
-    // TRUE if the registry has already been saved to disk
-    // At this point no more write operations should be made
-    // to the registry
-    bool _shutdown;
+	// Change tracking counter, is reset when saveToDisk() is called
+	unsigned int _changesSinceLastSave;
+
+	// TRUE if the registry has already been saved to disk
+	// At this point no more write operations should be made
+	// to the registry
+	bool _shutdown;
+
+	// Auto-save helper
+	std::unique_ptr<Autosaver> _autosaver;
 
 public:
 	/* Constructor:
@@ -60,67 +67,72 @@ public:
 	 */
 	XMLRegistry();
 
-	// The destructor exports all user settings to .xml files
-	virtual ~XMLRegistry();
-
-	xml::NodeList findXPath(const std::string& path);
+	xml::NodeList findXPath(const std::string& path) override;
 
 	/*	Checks whether a key exists in the XMLRegistry by querying the XPath
 	 */
-	bool keyExists(const std::string& key);
+	bool keyExists(const std::string& key) override;
 
 	/* Deletes this key and all its children,
 	 * this includes multiple instances nodes matching this key
 	 */
-	void deleteXPath(const std::string& path);
+	void deleteXPath(const std::string& path) override;
 
 	//	Adds a key <key> as child to <path> to the XMLRegistry (with the name attribute set to <name>)
-	xml::Node createKeyWithName(const std::string& path, const std::string& key, const std::string& name);
+	xml::Node createKeyWithName(const std::string& path, const std::string& key, const std::string& name) override;
 
 	/*	Adds a key to the XMLRegistry (without value, just the node)
 	 *  All required parent nodes are created automatically, if they don't exist */
-	xml::Node createKey(const std::string& key);
+	xml::Node createKey(const std::string& key) override;
 
 	// Set the value of the given attribute at the specified <path>.
 	void setAttribute(const std::string& path,
-					  const std::string& attrName,
-					  const std::string& attrValue);
+		const std::string& attrName,
+		const std::string& attrValue) override;
 
 	// Loads the string value of the given attribute of the node at <path>.
-	std::string getAttribute(const std::string& path, const std::string& attrName);
+	std::string getAttribute(const std::string& path, const std::string& attrName) override;
 
 	// Gets a key from the registry, user tree overrides default tree
-	std::string get(const std::string& key);
+	std::string get(const std::string& key) override;
 
 	// Sets the value of a key from the registry,
-	void set(const std::string& key, const std::string& value);
+	void set(const std::string& key, const std::string& value) override;
 
 	/* Appends a whole (external) XML file to the XMLRegistry. The toplevel nodes of this file
 	 * are appended to _topLevelNode (e.g. <darkradiant>) if parentKey is set to the empty string "",
 	 * otherwise they are imported as a child of the specified parentKey. Choose the target tree by
 	 * passing the correct enum value (e.g. treeUser for the user tree)
 	 */
-	void import(const std::string& importFilePath, const std::string& parentKey, Tree tree);
+	void import(const std::string& importFilePath, const std::string& parentKey, Tree tree) override;
 
 	// Dumps the current registry to std::out, for debugging purposes
-	void dump() const;
+	void dump() const override;
+
+	// Exports the user-tree to XML files in the user's settings path
+	void saveToDisk() override;
 
 	/* Saves a specified path from the user tree to the file <filename>.
 	 * Use "-" as <filename> if you want to write to std::out.
 	 */
-	void exportToFile(const std::string& key, const std::string& filename);
+	void exportToFile(const std::string& key, const std::string& filename) override;
 
-    sigc::signal<void> signalForKey(const std::string& key) const;
+	sigc::signal<void> signalForKey(const std::string& key) const override;
 
 	// RegisterableModule implementation
-	virtual const std::string& getName() const;
-	virtual const StringSet& getDependencies() const;
-	virtual void initialiseModule(const ApplicationContext& ctx);
+	const std::string& getName() const override;
+	const StringSet& getDependencies() const override;
+	void initialiseModule(const ApplicationContext& ctx) override;
 
 private:
+	void loadUserFileFromSettingsPath(const ApplicationContext& ctx,
+		const std::string& filename, const std::string& baseXPath);
+
 	void emitSignalForKey(const std::string& changedKey);
 
-    // Invoked after all modules have been uninitialised
-    void saveToDisk();
+	// Invoked after all modules have been uninitialised
+	void shutdown();
 };
 typedef std::shared_ptr<XMLRegistry> XMLRegistryPtr;
+
+}
