@@ -110,22 +110,11 @@ public:
 	bool intersectVolume(const VolumeTest& volume) const;
 	bool intersectVolume(const VolumeTest& volume, const Matrix4& localToWorld) const;
 
-	/**
-     * \brief
-     * Submit renderable geometry to a RenderableCollector (without l2w transform).
-     */
-	void submitRenderables(RenderableCollector& collector,
-                           const VolumeTest& volume,
-						   const IRenderEntity& entity) const;
-
-    /**
-     * \brief
-     * Submit renderable geometry to a RenderableCollector (with l2w transform).
-     */
-	void submitRenderables(RenderableCollector& collector,
-                           const VolumeTest& volume,
-                           const Matrix4& localToWorld,
-						   const IRenderEntity& entity) const;
+	// Frontend render methods for submitting the face to the given collector
+	void renderSolid(RenderableCollector& collector, const VolumeTest& volume,
+		const IRenderEntity& entity) const;
+	void renderWireframe(RenderableCollector& collector, const VolumeTest& volume,
+		const IRenderEntity& entity) const;
 
 	void testSelect(SelectionTest& test, SelectionIntersection& best);
 
