@@ -21,10 +21,6 @@
 #include "wxutil/dialog/Dialog.h"
 #include "wxutil/dialog/MessageBox.h"
 #include "wxutil/EntryAbortedException.h"
-#include "wxutil/menu/CommandMenuItem.h"
-
-#include "ui/layers/LayerControlDialog.h"
-#include "ui/layers/LayerOrthoContextMenuItem.h"
 
 #include <functional>
 
@@ -34,14 +30,6 @@ namespace scene
 namespace
 {
 	const char* const DEFAULT_LAYER_NAME = N_("Default");
-
-	const char* const LAYER_ICON = "layers.png";
-	const char* const CREATE_LAYER_TEXT = N_("Create Layer...");
-
-	const char* const ADD_TO_LAYER_TEXT = N_("Add to Layer...");
-	const char* const MOVE_TO_LAYER_TEXT = N_("Move to Layer...");
-	const char* const REMOVE_FROM_LAYER_TEXT = N_("Remove from Layer...");
-
 	const int DEFAULT_LAYER = 0;
 }
 
@@ -77,6 +65,9 @@ int LayerSystem::createLayer(const std::string& name, int layerID)
 	// Set the newly created layer to "visible"
 	_layerVisibility[result.first->first] = true;
 
+	// Layers have changed
+	onLayersChanged();
+
 	// Return the ID of the inserted layer
 	return result.first->first;
 }
@@ -127,9 +118,12 @@ void LayerSystem::deleteLayer(const std::string& name)
 		_activeLayer = DEFAULT_LAYER;
 	}
 
-	// Fire the visibility changed event to
-	// update the scenegraph and redraw the views
-	onLayerVisibilityChanged();
+	// Layers have changed
+	onLayersChanged();
+
+	// Nodes might have switched to default, fire the visibility 
+	// changed event, update the scenegraph and redraw the views
+	onNodeMembershipChanged();
 }
 
 void LayerSystem::foreachLayer(const LayerVisitFunc& visitor)
@@ -151,7 +145,8 @@ void LayerSystem::reset()
 	_layerVisibility[DEFAULT_LAYER] = true;
 
 	// Update the LayerControlDialog
-	ui::LayerControlDialog::Instance().refresh();
+	_layersChangedSignal.emit();
+	_layerVisibilityChangedSignal.emit();
 }
 
 bool LayerSystem::renameLayer(int layerID, const std::string& newLayerName)
@@ -170,6 +165,9 @@ bool LayerSystem::renameLayer(int layerID, const std::string& newLayerName)
 	// Rename that layer
 	i->second = newLayerName;
 
+	// Fire the update signal
+	onLayersChanged();
+
 	return true;
 }
 
@@ -276,20 +274,34 @@ void LayerSystem::setLayerVisibility(const std::string& layerName, bool visible)
 	setLayerVisibility(layerID, visible);
 }
 
-void LayerSystem::updateSceneGraphVisibility() {
+void LayerSystem::updateSceneGraphVisibility()
+{
 	UpdateNodeVisibilityWalker walker;
 	GlobalSceneGraph().root()->traverseChildren(walker);
-}
-
-void LayerSystem::onLayerVisibilityChanged() {
-	// Update all nodes
-	updateSceneGraphVisibility();
 
 	// Redraw
 	SceneChangeNotify();
+}
+
+void LayerSystem::onLayersChanged()
+{
+	_layersChangedSignal.emit();
+}
+
+void LayerSystem::onNodeMembershipChanged()
+{
+	_nodeMembershipChangedSignal.emit();
+
+	updateSceneGraphVisibility();
+}
+
+void LayerSystem::onLayerVisibilityChanged()
+{
+	// Update all nodes and views
+	updateSceneGraphVisibility();
 
 	// Update the LayerControlDialog
-	ui::LayerControlDialog::Instance().update();
+	_layerVisibilityChangedSignal.emit();
 }
 
 void LayerSystem::addSelectionToLayer(int layerID) {
@@ -302,7 +314,7 @@ void LayerSystem::addSelectionToLayer(int layerID) {
 	AddToLayerWalker walker(layerID);
 	GlobalSelectionSystem().foreachSelected(walker);
 
-	updateSceneGraphVisibility();
+	onNodeMembershipChanged();
 }
 
 void LayerSystem::addSelectionToLayer(const std::string& layerName) {
@@ -343,7 +355,7 @@ void LayerSystem::moveSelectionToLayer(int layerID) {
 	MoveToLayerWalker walker(layerID);
 	GlobalSelectionSystem().foreachSelected(walker);
 
-	updateSceneGraphVisibility();
+	onNodeMembershipChanged();
 }
 
 void LayerSystem::removeSelectionFromLayer(const std::string& layerName) {
@@ -370,12 +382,13 @@ void LayerSystem::removeSelectionFromLayer(int layerID) {
 	RemoveFromLayerWalker walker(layerID);
 	GlobalSelectionSystem().foreachSelected(walker);
 
-	updateSceneGraphVisibility();
+	onNodeMembershipChanged();
 }
 
-bool LayerSystem::updateNodeVisibility(const scene::INodePtr& node) {
+bool LayerSystem::updateNodeVisibility(const scene::INodePtr& node)
+{
 	// Get the list of layers the node is associated with
-	// greebo: TODO: Check if returning the LayerList by value is taxing.
+	// greebo: FIXME: Check if returning the LayerList by value is taxing.
 	LayerList layers = node->getLayers();
 
 	// We start with the assumption that a node is hidden
@@ -383,8 +396,10 @@ bool LayerSystem::updateNodeVisibility(const scene::INodePtr& node) {
 
 	// Cycle through the Node's layers, and show the node as soon as
 	// a visible layer is found.
-	for (LayerList::const_iterator i = layers.begin(); i != layers.end(); i++) {
-		if (_layerVisibility[*i]) {
+	for (int layerId : layers)
+	{
+		if (_layerVisibility[layerId])
+		{
 			// The layer is visible, set the visibility to true and quit
 			node->disable(Node::eLayered);
 			return true;
@@ -395,7 +410,8 @@ bool LayerSystem::updateNodeVisibility(const scene::INodePtr& node) {
 	return false;
 }
 
-void LayerSystem::setSelected(int layerID, bool selected) {
+void LayerSystem::setSelected(int layerID, bool selected)
+{
 	SetLayerSelectedWalker walker(layerID, selected);
 
     if (GlobalSceneGraph().root())
@@ -404,7 +420,23 @@ void LayerSystem::setSelected(int layerID, bool selected) {
     }
 }
 
-int LayerSystem::getLayerID(const std::string& name) const {
+sigc::signal<void> LayerSystem::signal_layersChanged()
+{
+	return _layersChangedSignal;
+}
+
+sigc::signal<void> LayerSystem::signal_layerVisibilityChanged()
+{
+	return _layerVisibilityChangedSignal;
+}
+
+sigc::signal<void> LayerSystem::signal_nodeMembershipChanged()
+{
+	return _nodeMembershipChangedSignal;
+}
+
+int LayerSystem::getLayerID(const std::string& name) const
+{
 	for (LayerMap::const_iterator i = _layers.begin(); i != _layers.end(); i++) {
 		if (i->second == name) {
 			// Name found, return the ID
@@ -415,7 +447,8 @@ int LayerSystem::getLayerID(const std::string& name) const {
 	return -1;
 }
 
-std::string LayerSystem::getLayerName(int layerID) const {
+std::string LayerSystem::getLayerName(int layerID) const 
+{
 	LayerMap::const_iterator found = _layers.find(layerID);
 
 	if (found != _layers.end()) {
@@ -431,7 +464,8 @@ bool LayerSystem::layerExists(int layerID) const
 	return _layers.find(layerID) != _layers.end();
 }
 
-int LayerSystem::getHighestLayerID() const {
+int LayerSystem::getHighestLayerID() const
+{
 	if (_layers.size() == 0) {
 		// Empty layer map, just return DEFAULT_LAYER
 		return DEFAULT_LAYER;
@@ -441,7 +475,8 @@ int LayerSystem::getHighestLayerID() const {
 	return _layers.rbegin()->first;
 }
 
-int LayerSystem::getLowestUnusedLayerID() {
+int LayerSystem::getLowestUnusedLayerID()
+{
 	for (int i = 0; i < INT_MAX; i++) {
 		if (_layers.find(i) == _layers.end()) {
 			// Found a free ID
@@ -453,7 +488,8 @@ int LayerSystem::getLowestUnusedLayerID() {
 }
 
 // RegisterableModule implementation
-const std::string& LayerSystem::getName() const {
+const std::string& LayerSystem::getName() const 
+{
 	static std::string _name(MODULE_LAYERSYSTEM);
 	return _name;
 }
@@ -466,8 +502,6 @@ const StringSet& LayerSystem::getDependencies() const
 	{
 		_dependencies.insert(MODULE_EVENTMANAGER);
 		_dependencies.insert(MODULE_COMMANDSYSTEM);
-		_dependencies.insert(MODULE_UIMANAGER);
-		_dependencies.insert(MODULE_ORTHOCONTEXTMENU);
 		_dependencies.insert(MODULE_MAPINFOFILEMANAGER);
 	}
 
@@ -482,10 +516,9 @@ void LayerSystem::initialiseModule(const ApplicationContext& ctx)
 	createLayer(_(DEFAULT_LAYER_NAME));
 
 	// Add command targets for the first 10 layer IDs here
-	for (int i = 0; i < 10; i++) {
-		_commandTargets.push_back(
-			LayerCommandTargetPtr(new LayerCommandTarget(i))
-		);
+	for (int i = 0; i < 10; i++)
+	{
+		_commandTargets.push_back(std::make_shared<LayerCommandTarget>(i));
 	}
 
 	// Register the "create layer" command
@@ -494,35 +527,10 @@ void LayerSystem::initialiseModule(const ApplicationContext& ctx)
         cmd::ARGTYPE_STRING|cmd::ARGTYPE_OPTIONAL);
 	IEventPtr ev = GlobalEventManager().addCommand("CreateNewLayer", "CreateNewLayer");
 
-	GlobalCommandSystem().addCommand("ToggleLayerControlDialog", ui::LayerControlDialog::toggle);
-	GlobalEventManager().addCommand("ToggleLayerControlDialog", "ToggleLayerControlDialog");
-
 	GlobalMapModule().signal_mapEvent().connect(
 		sigc::mem_fun(*this, &LayerSystem::onMapEvent)
 	);
 
-	// Create a new menu item connected to the CreateNewLayer command
-	wxutil::CommandMenuItemPtr menuItem(new wxutil::CommandMenuItem(
-		new wxutil::IconTextMenuItem(_(CREATE_LAYER_TEXT), LAYER_ICON),
-		"CreateNewLayer")
-	);
-
-	GlobalOrthoContextMenu().addItem(menuItem, ui::IOrthoContextMenu::SECTION_LAYER);
-
-	// Add the ortho context menu items
-	ui::LayerOrthoContextMenuItemPtr addMenu(new ui::LayerOrthoContextMenuItem(
-		_(ADD_TO_LAYER_TEXT), ui::LayerOrthoContextMenuItem::AddToLayer));
-
-	ui::LayerOrthoContextMenuItemPtr moveMenu(new ui::LayerOrthoContextMenuItem(
-		_(MOVE_TO_LAYER_TEXT), ui::LayerOrthoContextMenuItem::MoveToLayer));
-
-	ui::LayerOrthoContextMenuItemPtr removeMenu(new ui::LayerOrthoContextMenuItem(
-		_(REMOVE_FROM_LAYER_TEXT), ui::LayerOrthoContextMenuItem::RemoveFromLayer));
-
-	GlobalOrthoContextMenu().addItem(addMenu, ui::IOrthoContextMenu::SECTION_LAYER);
-	GlobalOrthoContextMenu().addItem(moveMenu, ui::IOrthoContextMenu::SECTION_LAYER);
-	GlobalOrthoContextMenu().addItem(removeMenu, ui::IOrthoContextMenu::SECTION_LAYER);
-
 	GlobalMapInfoFileManager().registerInfoFileModule(
 		std::make_shared<LayerInfoFileModule>()
 	);
@@ -567,9 +575,9 @@ void LayerSystem::createLayerCmd(const cmd::ArgumentList& args)
 		// Attempt to create the layer, this will return -1 if the operation fails
 		int layerID = createLayer(layerName);
 
-		if (layerID != -1) {
+		if (layerID != -1)
+		{
 			// Success, break the loop
-			ui::LayerControlDialog::Instance().refresh();
 			break;
 		}
 		else {
