@@ -10,15 +10,10 @@
 namespace map
 {
 
-IMapResourcePtr MapResourceManager::capture(const std::string& path)
+IMapResourcePtr MapResourceManager::loadFromPath(const std::string& path)
 {
 	// Create a new MapResource and return it.
-	MapResourcePtr newResource(new map::MapResource(path));
-
-	// Realise the new resource
-	newResource->realise();
-
-	return newResource;
+	return std::make_shared<MapResource>(path);
 }
 
 // RegisterableModule implementation
