@@ -35,6 +35,12 @@ public:
 	void unregisterExporter(const IModelExporterPtr& exporter) override;
 
 	IModelExporterPtr getExporter(const std::string& extension) override;
+
+	void foreachImporter(const std::function<void(const IModelImporterPtr&)>& functor) override;
+	void foreachExporter(const std::function<void(const IModelExporterPtr&)>& functor) override;
+
+private:
+	void postModuleInitialisation();
 };
 
 }
