@@ -119,20 +119,20 @@ void PatchTesselation::generateNormals()
 				around[k] = Vector3(0, 0, 0);
 				good[k] = false;
 
-				for (std::size_t dist = 1; dist <= 3; dist++)
+				for (int dist = 1; dist <= 3; dist++)
 				{
-					int x = i + neighbors[k][0] * dist;
-					int y = j + neighbors[k][1] * dist;
+					int x = static_cast<int>(i) + neighbors[k][0] * dist;
+					int y = static_cast<int>(j) + neighbors[k][1] * dist;
 
 					if (wrapWidth)
 					{
 						if (x < 0)
 						{
-							x = width - 1 + x;
+							x = static_cast<int>(width) - 1 + x;
 						}
-						else if (x >= width)
+						else if (x >= static_cast<int>(width))
 						{
-							x = 1 + x - width;
+							x = 1 + x - static_cast<int>(width);
 						}
 					}
 
@@ -140,15 +140,15 @@ void PatchTesselation::generateNormals()
 					{
 						if (y < 0)
 						{
-							y = height - 1 + y;
+							y = static_cast<int>(height) - 1 + y;
 						}
-						else if (y >= height)
+						else if (y >= static_cast<int>(height))
 						{
-							y = 1 + y - height;
+							y = 1 + y - static_cast<int>(height);
 						}
 					}
 
-					if (x < 0 || x >= width || y < 0 || y >= height)
+					if (x < 0 || x >= static_cast<int>(width) || y < 0 || y >= static_cast<int>(height))
 					{
 						break;					// edge of patch
 					}
@@ -335,9 +335,9 @@ void PatchTesselation::expandMesh()
 
 	if (width != _maxWidth)
 	{
-		for (int j = height - 1; j >= 0; j--)
+		for (int j = static_cast<int>(height) - 1; j >= 0; j--)
 		{
-			for (int i = width - 1; i >= 0; i--)
+			for (int i = static_cast<int>(width) - 1; i >= 0; i--)
 			{
 				vertices[j*_maxWidth + i] = vertices[j*width + i];
 			}
@@ -345,7 +345,7 @@ void PatchTesselation::expandMesh()
 	}
 }
 
-void PatchTesselation::resizeExpandedMesh(int newHeight, int newWidth)
+void PatchTesselation::resizeExpandedMesh(std::size_t newHeight, std::size_t newWidth)
 {
 	if (newHeight <= _maxHeight && newWidth <= _maxWidth)
 	{
@@ -358,9 +358,9 @@ void PatchTesselation::resizeExpandedMesh(int newHeight, int newWidth)
 	}
 
 	// space out verts for new height and width
-	for (int j = _maxHeight - 1; j >= 0; j--)
+	for (int j = static_cast<int>(_maxHeight) - 1; j >= 0; j--)
 	{
-		for (int i = _maxWidth - 1; i >= 0; i--)
+		for (int i = static_cast<int>(_maxWidth) - 1; i >= 0; i--)
 		{
 			vertices[j*newWidth + i] = vertices[j*_maxWidth + i];
 		}
@@ -555,7 +555,7 @@ void PatchTesselation::subdivideMesh()
 			lerpVert(vertices[i*_maxWidth + j + 1], vertices[i*_maxWidth + j + 2], next);
 			lerpVert(prev, next, mid);
 
-			for (int k = width - 1; k > j + 3; k--)
+			for (int k = static_cast<int>(width) - 1; k > static_cast<int>(j) + 3; k--)
 			{
 				vertices[i*_maxWidth + k] = vertices[i*_maxWidth + k - 2];
 			}
@@ -571,7 +571,7 @@ void PatchTesselation::subdivideMesh()
 	// vertical subdivisions
 	for (std::size_t j = 0; j + 2 < height; j += 2)
 	{
-		int i;
+		std::size_t i;
 
 		// check subdivided midpoints against control points
 		for (i = 0; i < width; i++)
@@ -620,7 +620,7 @@ void PatchTesselation::subdivideMesh()
 			lerpVert(vertices[(j + 1)*_maxWidth + i], vertices[(j + 2)*_maxWidth + i], next);
 			lerpVert(prev, next, mid);
 
-			for (int k = height - 1; k > j + 3; k--)
+			for (int k = static_cast<int>(height) - 1; k > static_cast<int>(j) + 3; k--)
 			{
 				vertices[k*_maxWidth + i] = vertices[(k - 2)*_maxWidth + i];
 			}
