@@ -6,6 +6,7 @@
 #include "math/Matrix4.h"
 #include "modulesystem/StaticModule.h"
 #include "backend/GLProgramFactory.h"
+#include "debugging/debugging.h"
 
 #include <functional>
 
@@ -48,7 +49,15 @@ OpenGLRenderSystem::OpenGLRenderSystem() :
 	// hence it will be attached in initialiseModule().
     if (module::ModuleRegistry::Instance().moduleExists(MODULE_SHADERSYSTEM))
 	{
-		GlobalMaterialManager().attach(*this);
+		_materialDefsLoaded = GlobalMaterialManager().signal_DefsLoaded().connect(
+			sigc::mem_fun(*this, &OpenGLRenderSystem::realise));
+		_materialDefsUnloaded = GlobalMaterialManager().signal_DefsUnloaded().connect(
+			sigc::mem_fun(*this, &OpenGLRenderSystem::unrealise));
+
+		if (GlobalMaterialManager().isRealised())
+		{
+			realise();
+		}
 	}
 
     // If the openGL module is already initialised and a shared context is created
@@ -62,12 +71,8 @@ OpenGLRenderSystem::OpenGLRenderSystem() :
 
 OpenGLRenderSystem::~OpenGLRenderSystem()
 {
-	// The static default rendersystem won't use this, it will detach itself
-	// in the shutdownModule() method.
-    if (module::ModuleRegistry::Instance().moduleExists(MODULE_SHADERSYSTEM))
-	{
-		GlobalMaterialManager().detach(*this);
-	}
+	_materialDefsLoaded.disconnect();
+	_materialDefsUnloaded.disconnect();
 }
 
 ShaderPtr OpenGLRenderSystem::capture(const std::string& name)
@@ -398,6 +403,13 @@ void OpenGLRenderSystem::extensionsInitialised()
 		}
 	}
 
+	// Now that GL extensions are done, we can realise our shaders
+	// This was previously done explicitly by the OpenGLModule after the
+	// shared context was created. But we need realised shaders before
+	// we can fire off the "extensions initialised" signal, map loading
+	// code might rely on materials being constructed.
+	realise();
+
 	// Notify all our observers
 	_sigExtensionsInitialised();
 }
@@ -524,7 +536,15 @@ void OpenGLRenderSystem::initialiseModule(const ApplicationContext& ctx)
 {
 	rMessage() << getName() << "::initialiseModule called." << std::endl;
 
-	GlobalMaterialManager().attach(*this);
+	_materialDefsLoaded = GlobalMaterialManager().signal_DefsLoaded().connect(
+		sigc::mem_fun(*this, &OpenGLRenderSystem::realise));
+	_materialDefsUnloaded = GlobalMaterialManager().signal_DefsUnloaded().connect(
+		sigc::mem_fun(*this, &OpenGLRenderSystem::unrealise));
+
+	if (GlobalMaterialManager().isRealised())
+	{
+		realise();
+	}
 
 	// greebo: Don't realise the module yet, this must wait
 	// until the shared GL context has been created (this
@@ -533,7 +553,8 @@ void OpenGLRenderSystem::initialiseModule(const ApplicationContext& ctx)
 
 void OpenGLRenderSystem::shutdownModule()
 {
-	GlobalMaterialManager().detach(*this);
+	_materialDefsLoaded.disconnect();
+	_materialDefsUnloaded.disconnect();
 }
 
 // Define the static ShaderCache module
