@@ -4,7 +4,6 @@
 
 #include "irender.h"
 #include "ishaders.h"
-#include "moduleobservers.h"
 #include "string/string.h"
 
 #include <list>
@@ -17,8 +16,8 @@ class OpenGLRenderSystem;
 /**
  * Implementation of the Shader class.
  */
-class OpenGLShader
-: public Shader
+class OpenGLShader : 
+	public Shader
 {
     // The state manager we will be inserting/removing OpenGL states from
     OpenGLRenderSystem& _renderSystem;
@@ -34,7 +33,10 @@ class OpenGLShader
     bool _isVisible;
 
 	std::size_t _useCount;
-	ModuleObservers m_observers;
+
+	// Observers attached to this Shader
+	typedef std::set<Observer*> Observers;
+	Observers _observers;
 
 private:
 
@@ -69,8 +71,6 @@ private:
     void insertPasses();
     void removePasses();
     
-    bool realised() const;
-
 public:
     /// Construct and initialise
     OpenGLShader(OpenGLRenderSystem& renderSystem);
@@ -93,8 +93,10 @@ public:
     void incrementUsed() override;
     void decrementUsed() override;
 
-    void attach(ModuleObserver& observer) override;
-    void detach(ModuleObserver& observer) override;
+	void attachObserver(Observer& observer) override;
+	void detachObserver(Observer& observer) override;
+
+	bool isRealised() override;
 
 	/**
 	 * Realise this shader, setting the name in the process.
