@@ -1,7 +1,9 @@
 #pragma once
 
+#include "irender.h"
 #include "imousetool.h"
 #include "render/View.h"
+#include "math/Vector2.h"
 
 class SelectionSystem;
 
@@ -23,6 +25,18 @@ private:
 
     SelectionSystem& _selectionSystem;
 
+	Matrix4 _pivot2worldStart;
+	bool _manipulationActive;
+
+	Vector2 _deviceStart;
+	bool _undoBegun;
+
+#ifdef _DEBUG
+	std::string _debugText;
+#endif
+
+	ShaderPtr _pointShader;
+
 public:
     ManipulateMouseTool(SelectionSystem& selectionSystem);
 
@@ -38,6 +52,17 @@ public:
 
     virtual unsigned int getPointerMode() override;
     virtual unsigned int getRefreshMode() override;
+
+	void renderOverlay() override;
+	void render(RenderSystem& renderSystem, RenderableCollector& collector, const VolumeTest& volume) override;
+
+private:
+	bool selectManipulator(const render::View& view, const Vector2& devicePoint, const Vector2& deviceEpsilon);
+	void handleMouseMove(const render::View& view, const Vector2& devicePoint);
+	void freezeTransforms();
+	void endMove();
+	void cancelMove();
+	bool nothingSelected() const;
 };
 
 }
