@@ -3,10 +3,9 @@
 #include <stdexcept>
 #include "i18n.h"
 #include "itextstream.h"
-#include <boost/algorithm/string/split.hpp>
-#include <boost/algorithm/string/join.hpp>
-#include <boost/algorithm/string/classification.hpp>
-#include <boost/format.hpp>
+#include "string/split.h"
+#include "string/join.h"
+#include <fmt/format.h>
 
 #include "PreferenceItems.h"
 
@@ -16,7 +15,7 @@ namespace settings
 PreferencePage::PreferencePage(const std::string& name, const PreferencePagePtr& parentPage) :
 	_name(name)
 {
-	_title = (boost::format(_("%s Settings")) % _name).str();
+	_title = fmt::format(_("{0} Settings"), _name);
 
 	// Construct the _path member value
 	if (parentPage && !parentPage->getPath().empty())
@@ -53,7 +52,7 @@ PreferencePage& PreferencePage::createOrFindPage(const std::string& path)
 {
 	// Split the path into parts
 	std::list<std::string> parts;
-	boost::algorithm::split(parts, path, boost::algorithm::is_any_of("/"));
+	string::split(parts, path, "/");
 
 	if (parts.empty())
 	{
@@ -85,7 +84,7 @@ PreferencePage& PreferencePage::createOrFindPage(const std::string& path)
 	{
 		// We have still more parts, split off the first part
 		parts.pop_front();
-		std::string subPath = boost::algorithm::join(parts, "/");
+		std::string subPath = string::join(parts, "/");
 
 		// Pass the call to the child
 		return child->createOrFindPage(subPath);
