@@ -39,7 +39,7 @@
 #include <wx/artprov.h>
 
 #include <functional>
-#include <boost/algorithm/string/replace.hpp>
+#include "string/replace.h"
 #include <regex>
 
 namespace ui {
@@ -619,8 +619,8 @@ std::string EntityInspector::cleanInputString(const std::string &input)
 {
     std::string ret = input;
 
-    boost::algorithm::replace_all(ret, "\n", "");
-    boost::algorithm::replace_all(ret, "\r", "");
+    string::replace_all(ret, "\n", "");
+	string::replace_all(ret, "\r", "");
 
     return ret;
 }
@@ -1191,8 +1191,7 @@ void EntityInspector::getEntityFromSelectionSystem()
 		std::size_t ent(0), prim(0);
 		selection::algorithm::getSelectionIndex(ent, prim);
 
-		_primitiveNumLabel->SetLabelText(
-			(boost::format(_("Entity %d")) % ent).str());
+		_primitiveNumLabel->SetLabelText(fmt::format(_("Entity {0}"), ent));
     }
     else
     {
@@ -1203,8 +1202,7 @@ void EntityInspector::getEntityFromSelectionSystem()
 		std::size_t ent(0), prim(0);
 		selection::algorithm::getSelectionIndex(ent, prim);
 
-		_primitiveNumLabel->SetLabelText(
-			(boost::format(_("Entity %d, Primitive %d")) % ent % prim).str());
+		_primitiveNumLabel->SetLabelText(fmt::format(_("Entity {0}, Primitive {1}"), ent, prim));
     }
 }
 
