@@ -23,10 +23,13 @@ PrefPage::PrefPage(wxWindow* parent, const settings::PreferencePage& settingsPag
 	wxBoxSizer* overallVBox = new wxBoxSizer(wxVERTICAL);
 	GetSizer()->Add(overallVBox, 1, wxEXPAND | wxALL, 12);
 
-	// Create the label
-	wxStaticText* titleLabel = new wxStaticText(this, wxID_ANY, _settingsPage.getTitle());
-	titleLabel->SetFont(titleLabel->GetFont().Bold());
-	overallVBox->Add(titleLabel, 0, wxBOTTOM, 12);
+	// Create the label, unless the page is empty
+	if (!settingsPage.isEmpty())
+	{
+		wxStaticText* titleLabel = new wxStaticText(this, wxID_ANY, _settingsPage.getTitle());
+		titleLabel->SetFont(titleLabel->GetFont().Bold());
+		overallVBox->Add(titleLabel, 0, wxBOTTOM, 12);
+	}
 
 	_table = new wxFlexGridSizer(1, 2, 6, 12);
 	overallVBox->Add(_table, 1, wxEXPAND | wxLEFT, 6); // another 12 pixels to the left
